Thin wrapper around the inventory-driven extension registry.
Re-exported here so that the extension framework, the schema
collector, and crate::ConfigLoader are all reachable from a single
re-export point in this crate.
Thin wrapper around the inventory-driven extension registry.
Re-exported here so that the extension framework, the schema
collector, and crate::ConfigLoader are all reachable from a single
re-export point in this crate.